@@ -31,7 +31,7 @@ describe AccessToken do
       expect(target.params['foo']).to eq('bar')
     end
 
-    def assert_initialized_token(target)
+    def assert_initialized_token(target) # rubocop:disable Metrics/AbcSize
       expect(target.token).to eq(token)
       expect(target).to be_expires
       expect(target.params.keys).to include('foo')
@@ -44,6 +44,13 @@ describe AccessToken do
       assert_initialized_token(target)
     end
 
+    it 'does not modify opts hash' do
+      hash = {:access_token => token, :expires_at => Time.now.to_i}
+      hash_before = hash.dup
+      AccessToken.from_hash(client, hash)
+      expect(hash).to eq(hash_before)
+    end
+
     it 'initalizes with a form-urlencoded key/value string' do
       kvform = "access_token=#{token}&expires_at=#{Time.now.to_i + 200}&foo=bar"
       target = AccessToken.from_kvform(client, kvform)
@@ -57,6 +64,13 @@ describe AccessToken do
       expect(target.options[:mode]).to eq(:body)
     end
 
+    it 'does not modify opts hash' do
+      opts = {:param_name => 'foo', :header_format => 'Bearer %', :mode => :body}
+      opts_before = opts.dup
+      AccessToken.new(client, token, opts)
+      expect(opts).to eq(opts_before)
+    end
+
     it 'initializes with a string expires_at' do
       hash = {:access_token => token, :expires_at => '1361396829', 'foo' => 'bar'}
       target = AccessToken.from_hash(client, hash)
@@ -132,7 +146,6 @@ describe AccessToken do
       allow(Time).to receive(:now).and_return(@now)
       expect(access).to be_expired
     end
-
   end
 
   describe '#refresh!' do
